@@ -1,10 +1,11 @@
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
+from sqlalchemy.orm.session import Session as BaseSession
+from sqlalchemy.engine import Engine as BaseEngine
 from sqlalchemy.exc import SQLAlchemyError
 import LibHanger.Library.uwLogger as Logger
 from LibHanger.Library.uwLogger import loggerDecorator
 from LibHanger.Library.uwConfig import cmnConfig
-from LibHanger.Models.recset import recset
 
 class uwDataAccess:
     
@@ -21,12 +22,12 @@ class uwDataAccess:
         self.__config = config
         """ 共通設定 """
 
-        self.__session = None
+        self.__session:BaseSession = None
         """ DBセッション """
         
-        self.__engine = None
-        """  sqlalchemy - engine"""
-    
+        self.__engine:BaseEngine = None
+        """  sqlalchemy - engine """
+
     @property
     def session(self):
         
@@ -36,6 +37,15 @@ class uwDataAccess:
         
         return self.__session
     
+    @property
+    def autoCommit(self):
+        
+        """
+        autocommit
+        """
+        
+        return self.__session.autocommit
+    
     def getConnectionString(self):
 
         """ 
@@ -56,7 +66,7 @@ class uwDataAccess:
                                             self.__config.ConnectionString.DatabaseName)
 
     @loggerDecorator("Open Seesion")
-    def openSession(self):
+    def openSession(self, __autocommit = False):
         
         """ 
         session開く
@@ -64,30 +74,21 @@ class uwDataAccess:
         Parameters
         ----------
         
-        None
+        __autocommit : bool
+            autocommit
         """
 
         # engine生成
         self.__engine = self.createEngine()
     
         # session生成
-        self.__session = self.createSession(self.__engine)
+        self.__session = self.createSession(self.__engine, __autocommit)
 
-    def openRecset(self, t, w):
+    @loggerDecorator("Begin Transaction")
+    def beginTransaction(self):
         
-        """ 
-        レコードセット開く
-        
-        Parameters
-        ----------
-        
-        t: Any
-            Modelクラス
-        w : any
-            where条件
-        """
-
-        return recset[t](t, self.__session, w)
+        # トランザクション開始
+        self.__session.begin()
     
     @loggerDecorator("Commit Seesion")
     def commit(self):
@@ -103,7 +104,10 @@ class uwDataAccess:
         
         # Session - Commit
         self.__session.commit()
-    
+        
+        # autocommit - On
+        self.__session.autocommit = True
+
     @loggerDecorator("Commit Rollback")
     def rollback(self):
 
@@ -119,6 +123,9 @@ class uwDataAccess:
         # Session - Rollback
         self.__session.rollback()
         
+        # autocommit - On
+        self.__session.autocommit = True
+
     @loggerDecorator("Close Seesion")
     def closeSession(self):
         
@@ -133,7 +140,7 @@ class uwDataAccess:
         
         # Seesion - Close
         self.__session.close()
-       
+        
     @loggerDecorator("Create Engine")
     def createEngine(self):
 
@@ -156,7 +163,7 @@ class uwDataAccess:
         return eng
 
     @loggerDecorator("Connection - DataBase")
-    def dbConnect(self, eng):
+    def dbConnect(self, eng:BaseEngine):
 
         """ 
         database接続 
@@ -171,7 +178,7 @@ class uwDataAccess:
         return eng.connect()
     
     @loggerDecorator("Create - Session")
-    def createSession(self, eng):
+    def createSession(self, eng, __autocommit):
 
         """ 
         sqlalchemy用セッション生成 
@@ -180,10 +187,12 @@ class uwDataAccess:
         ----------
         eng : _engine.Engine
             Engine
+        __autocommit : bool
+            autocommit
         """
 
         # sessionmakerで返す
-        Session = sessionmaker(bind=eng)
+        Session = sessionmaker(bind=eng, autocommit=__autocommit)
 
         # 戻り値として返す
         return Session()
