@@ -1,14 +1,14 @@
 import inspect
 import pandas as pd
 import copy
+import LibHanger.Library.uwLogger as Logger
 from typing import TypeVar, Generic
 from enum import Enum
 from sqlalchemy.exc import SQLAlchemyError
 from sqlalchemy import and_
-from sqlalchemy.orm.session import Session as BaseSession
-import LibHanger.Library.uwLogger as Logger
 from LibHanger.Models.fields import fields
 from LibHanger.Library.DataAccess.Base.uwDataAccess import uwDataAccess
+from LibHanger.Library.uwDeclare import uwDeclare as en
 
 T = TypeVar('T')
 
@@ -643,7 +643,7 @@ class recset(Generic[T]):
 
         return self.update(True)
         
-    def update(self, upsert = False):
+    def update(self, upsert = False) -> en.resultRegister:
         
         """
         データ更新(通常用)
@@ -653,8 +653,6 @@ class recset(Generic[T]):
             rowState = addedとした行を追加する際に主キー違反していればSQLAlchemyErrorとなる。\n
             recset側でDBとの制約を解決していればupsertよりこちらのほうが速度は上
         """
-
-        result = False
         
         try:
         
@@ -675,13 +673,16 @@ class recset(Generic[T]):
                 self.__session.commit()
 
             # 処理結果セット
-            result = True
+            result = en.resultRegister.success
             
         except SQLAlchemyError as e:
             
             # エラーログ出力
             Logger.logging.error(e)
 
+            # 処理結果セット
+            result = en.resultRegister.failure
+
             # Rollback
             if self.__da.autoCommit:
                 self.__session.rollback()
